**NOTE** These backends are not documented here, to avoid adding a dependency
to building the docs.

:mod:`matplotlib.backends.backend_gtk3agg`
==========================================

.. module:: matplotlib.backends.backend_gtk3agg

:mod:`matplotlib.backends.backend_gtk3cairo`
============================================

.. module:: matplotlib.backends.backend_gtk3cairo
